@@ -14,8 +14,14 @@ Functions for returning the canonical host name of the remote site.
 */
 
 /*
- * $Id: canohost.c,v 1.2 1996/10/29 22:35:11 kivinen Exp $
+ * $Id: canohost.c,v 1.4 1998/05/23 20:21:01 kivinen Exp $
  * $Log: canohost.c,v $
+ * Revision 1.4  1998/05/23  20:21:01  kivinen
+ * 	Changed () -> (void).
+ *
+ * Revision 1.3  1997/03/19  15:59:45  kivinen
+ * 	Limit hostname to 255 characters.
+ *
  * Revision 1.2  1996/10/29 22:35:11  kivinen
  * 	log -> log_msg.
  *
@@ -51,7 +57,7 @@ char *get_remote_hostname(int socket)
   struct sockaddr_in from;
   int fromlen, i;
   struct hostent *hp;
-  char name[512];
+  char name[255];
 
   /* Get IP address of client. */
   fromlen = sizeof(from);
@@ -161,7 +167,7 @@ static char *canonical_host_ip = NULL;
    connection.  The host name is cached, so it is efficient to call this 
    several times. */
 
-const char *get_canonical_hostname()
+const char *get_canonical_hostname(void)
 {
   int fromlen, tolen;
   struct sockaddr_in from, to;
@@ -206,7 +212,7 @@ const char *get_canonical_hostname()
 /* Returns the IP-address of the remote host as a string.  The returned
    string need not be freed. */
 
-const char *get_remote_ipaddr()
+const char *get_remote_ipaddr(void)
 {
   struct sockaddr_in from, to;
   int fromlen, tolen, socket;
@@ -284,7 +290,7 @@ int get_peer_port(int sock)
 
 /* Returns the port number of the remote host.  */
 
-int get_remote_port()
+int get_remote_port(void)
 {
   int socket;
   int fromlen, tolen;
