@@ -12,8 +12,15 @@ Created: Wed Apr 19 16:50:42 1995 ylo
 */
 
 /*
- * $Id: cipher.h,v 1.7 1997/03/26 07:11:22 kivinen Exp $
+ * $Id: cipher.h,v 1.9 1998/04/30 01:51:26 kivinen Exp $
  * $Log: cipher.h,v $
+ * Revision 1.9  1998/04/30  01:51:26  kivinen
+ * 	Reserved cipher number 7 to Bernard Perrot
+ * 	<perrot@lal.in2p3.fr> for some weak 40 bit encryption method.
+ *
+ * Revision 1.8  1998/03/27 17:24:03  kivinen
+ * 	Removed TSS.
+ *
  * Revision 1.7  1997/03/26 07:11:22  kivinen
  * 	Fixed prototypes.
  *
@@ -52,9 +59,6 @@ Created: Wed Apr 19 16:50:42 1995 ylo
 #include "idea.h"
 #endif /* WITHOUT_IDEA */
 #include "des.h"
-#ifdef WITH_TSS
-#include "tss.h"
-#endif /* WITH_TSS */
 #ifdef WITH_ARCFOUR
 #include "arcfour.h"
 #endif /* WITH_ARCFOUR */
@@ -69,9 +73,10 @@ Created: Wed Apr 19 16:50:42 1995 ylo
 #define SSH_CIPHER_IDEA		1 /* IDEA CFB */
 #define SSH_CIPHER_DES		2 /* DES CBC */
 #define SSH_CIPHER_3DES		3 /* 3DES CBC */
-#define SSH_CIPHER_TSS		4 /* TRI's Simple Stream encryption CBC */
 #define SSH_CIPHER_ARCFOUR	5 /* Arcfour */
 #define SSH_CIPHER_BLOWFISH     6 /* Bruce Schneier's Blowfish */
+#define SSH_CIPHER_RESERVED	7 /* Reserved for 40 bit crippled encryption,
+				     Bernard Perrot <perrot@lal.in2p3.fr> */
 
 typedef struct {
   unsigned int type;
@@ -96,9 +101,6 @@ typedef struct {
       DESContext key3;
       unsigned char iv3[8];
     } des3;
-#ifdef WITH_TSS
-    struct tss_context tss;
-#endif /* WITH_TSS */
 #ifdef WITH_ARCFOUR
     ArcfourContext arcfour;
 #endif
