@@ -15,9 +15,12 @@ output to the system log.
 */
 
 /*
- * $Id: log-server.c,v 1.5 1998/01/02 06:18:49 kivinen Exp $
+ * $Id: log-server.c,v 1.6 1998/05/23 20:21:43 kivinen Exp $
  * $Log: log-server.c,v $
- * Revision 1.5  1998/01/02 06:18:49  kivinen
+ * Revision 1.6  1998/05/23  20:21:43  kivinen
+ * 	Changed () -> (void).
+ *
+ * Revision 1.5  1998/01/02  06:18:49  kivinen
  * 	Fixed kerberos ticket name handling.
  *
  * Revision 1.4  1997/04/17 04:05:51  kivinen
@@ -253,7 +256,7 @@ void fatal_remove_cleanup(void (*proc)(void *context), void *context)
 	(unsigned long)proc, (unsigned long)context);
 }
 
-static void do_fatal_cleanups()
+static void do_fatal_cleanups(void)
 {
   struct fatal_cleanup *cu, *next_cu;
   static int fatal_called = 0;
