@@ -1,15 +1,11 @@
 #ifndef MD5_H
 #define MD5_H
 
-#if SIZEOF_LONG == 8
-typedef unsigned int uint32;
-#else
-typedef unsigned long uint32;
-#endif
+typedef word32 md5_uint32;
 
 struct MD5Context {
-	uint32 buf[4];
-	uint32 bits[2];
+	md5_uint32 buf[4];
+	md5_uint32 bits[2];
 	unsigned char in[64];
 };
 
@@ -17,7 +13,7 @@ void MD5Init(struct MD5Context *context);
 void MD5Update(struct MD5Context *context, unsigned char const *buf,
 	       unsigned len);
 void MD5Final(unsigned char digest[16], struct MD5Context *context);
-void MD5Transform(uint32 buf[4], uint32 const in[16]);
+void MD5Transform(md5_uint32 buf[4], const unsigned char in[64]);
 
 /*
  * This is needed to make RSAREF happy on some MS-DOS compilers.
