@@ -16,8 +16,11 @@ of X11, TCP/IP, and authentication connections.
 */
 
 /*
- * $Id: ssh.c,v 1.30 1998/05/23 20:25:44 kivinen Exp $
+ * $Id: ssh.c,v 1.31 1998/07/08 00:47:18 kivinen Exp $
  * $Log: ssh.c,v $
+ * Revision 1.31  1998/07/08 00:47:18  kivinen
+ * 	Fixed typo (privileged).
+ *
  * Revision 1.30  1998/05/23  20:25:44  kivinen
  * 	Changed () -> (void). Added check that {ssh,slogin}{,1}{.old}
  * 	are known program names, not host names. Added missing break
@@ -300,7 +303,7 @@ void usage(void)
 #endif /* WITH_BLOWFISH */
 	  "``3des''\n");
   fprintf(stderr, "  -p port     Connect to this port.  Server must be on the same port.\n");
-  fprintf(stderr, "  -P          Don't use priviledged source port.\n");
+  fprintf(stderr, "  -P          Don't use privileged source port.\n");
 #ifndef SSH_NO_PORT_FORWARDING
   fprintf(stderr, "  -L listen-port:host:port   Forward local port to remote address\n");
   fprintf(stderr, "  -R listen-port:host:port   Forward remote port to local address\n");
@@ -397,7 +400,7 @@ int main(int ac, char **av)
   struct stat st;
   struct passwd *pw, pwcopy;
   int interactive = 0, dummy;
-  int use_priviledged_port = 1;
+  int use_privileged_port = 1;
   uid_t original_effective_uid;
 #ifdef SIGWINCH
   struct winsize ws;
@@ -664,7 +667,7 @@ int main(int ac, char **av)
 	  break;
 
 	case 'P':
-	  use_priviledged_port = 0;
+	  use_privileged_port = 0;
 	  break;
 
 	case 'g':
@@ -761,20 +764,20 @@ int main(int ac, char **av)
       fatal("rsh_connect returned");
     }
 
-  if (use_priviledged_port && !options.use_priviledged_port)
+  if (use_privileged_port && !options.use_privileged_port)
     {
-      use_priviledged_port = 0;
+      use_privileged_port = 0;
     }
   if (!options.rhosts_authentication && !options.rhosts_rsa_authentication)
     {
-      use_priviledged_port = 0;
+      use_privileged_port = 0;
     }
   /* Open a connection to the remote host.  This needs root privileges if
      rhosts_authentication is true.  Note that the random_state is not
      yet used by this call, although a pointer to it is stored, and thus it
      need not be initialized. */
   ok = ssh_connect(host, options.port, options.connection_attempts,
-		   !use_priviledged_port,
+		   !use_privileged_port,
 		   original_real_uid, options.proxy_command, &random_state);
 
   /* Check if the connection failed, and try "rsh" if appropriate. */
